@@ -6,6 +6,7 @@ package dao
 import (
 	"context"
 	"fmt"
+	"log/slog"
 	"regexp"
 	"strings"
 
@@ -13,7 +14,7 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/render"
-	"github.com/rs/zerolog/log"
+	"github.com/derailed/k9s/internal/slogs"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 )
@@ -45,7 +46,7 @@ func (p *PortForward) List(ctx context.Context, _ string) ([]runtime.Object, err
 
 	config, err := config.NewBench(benchFile)
 	if err != nil {
-		log.Debug().Msgf("No custom benchmark config file found: %q", benchFile)
+		slog.Debug("No custom benchmark config file found", slogs.FileName, benchFile)
 	}
 
 	ff, cc := p.getFactory().Forwarders(), config.Benchmarks.Containers
@@ -92,7 +93,10 @@ func BenchConfigFor(benchFile, path string) config.BenchConfig {
 	def := config.DefaultBenchSpec()
 	cust, err := config.NewBench(benchFile)
 	if err != nil {
-		log.Debug().Msgf("No custom benchmark config file found. Using default: %q", benchFile)
+		slog.Debug("No custom benchmark config file found. Using default",
+			slogs.FileName, benchFile,
+			slogs.Error, err,
+		)
 		return def
 	}
 	if b, ok := cust.Benchmarks.Containers[PodToKey(path)]; ok {
