@@ -8,7 +8,7 @@ import (
 	"testing"
 	"time"
 
-	"github.com/derailed/k9s/internal/config"
+	"github.com/derailed/k9s/internal/config/mock"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/stretchr/testify/assert"
@@ -25,7 +25,7 @@ func TestFlash(t *testing.T) {
 		"err":  {l: model.FlashErr, i: "hello", e: "😡 hello\n"},
 	}
 
-	a := ui.NewApp(config.NewConfig(nil), "test")
+	a := ui.NewApp(mock.NewMockConfig(), "test")
 	f := ui.NewFlash(a)
 	f.SetTestMode(true)
 	ctx, cancel := context.WithCancel(context.Background())
